package com.fs.course.mapper;

import com.fs.course.domain.FsUserTalent;
import org.apache.ibatis.annotations.Update;

import java.util.List;

/**
 * 达人Mapper接口
 *
 * @author fs
 * @date 2024-05-31
 */
public interface FsUserTalentMapper
{
    /**
     * 查询达人
     *
     * @param talentId 达人主键
     * @return 达人
     */
    public FsUserTalent selectFsUserTalentByTalentId(Long talentId);

    /**
     * 查询达人列表
     *
     * @param fsUserTalent 达人
     * @return 达人集合
     */
    public List<FsUserTalent> selectFsUserTalentList(FsUserTalent fsUserTalent);

    /**
     * 新增达人
     *
     * @param fsUserTalent 达人
     * @return 结果
     */
    public int insertFsUserTalent(FsUserTalent fsUserTalent);

    /**
     * 修改达人
     *
     * @param fsUserTalent 达人
     * @return 结果
     */
    public int updateFsUserTalent(FsUserTalent fsUserTalent);

    /**
     * 删除达人
     *
     * @param talentId 达人主键
     * @return 结果
     */
    public int deleteFsUserTalentByTalentId(Long talentId);

    /**
     * 批量删除达人
     *
     * @param talentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFsUserTalentByTalentIds(Long[] talentIds);

    @Update("update fs_user_talent set fans=fans+1 where talent_id=#{talentId}")
    int addFans(Long talentId);


    @Update("update fs_user_talent set fans=fans-1 where talent_id=#{talentId}")
    int minusFans(Long talentId);
}
